from whru.tensorboard import get_SummaryWriter
from whru.utils import get_datetime_str, path_join, get_abs_path

if __name__ == "__main__":
    print(get_abs_path(__file__), get_datetime_str())
    writer = get_SummaryWriter(
        path_join(get_abs_path(__file__), "../test_data", get_datetime_str())
    )
    writer.add_scalar("acc", 0.1, 0)



from setuptools import setup

setup(
    name='whru',
    version='0.2',
    description='My custom Python module',
    author='whr819987540',
    author_email='steeliron550@gmail.com',
    packages=['whru'],
    install_requires=[
        "torch>=1.7.0",
        "tensorflow>=2.0.2",
    ],
)